@@ -5,10 +5,10 @@ from threading import Thread
 from typing import Set, List, Tuple, Dict, Iterable, Optional, Generator, Pattern
 
 from bauh.api.abstract.handler import ProcessWatcher
+from bauh.commons.version_util import match_required_version
 from bauh.gems.arch import pacman, message, sorting, confirmation
 from bauh.gems.arch.aur import AURClient
 from bauh.gems.arch.exceptions import PackageNotFoundException
-from bauh.gems.arch.version import match_required_version
 from bauh.view.util.translation import I18n
 
 
@@ -288,7 +288,7 @@ class DependenciesAnalyser:
                             if not version_required or match_required_version(pkgdata['v'], exp_op,
                                                                               version_required):
                                 yield pkgname, pkgdata
-                        except:
+                        except Exception:
                             self._log.warning(f"Could not compare AUR package '{pkgname}' version '{pkgdata['v']}' "
                                               f"with the dependency expression '{dep_exp}'")
                             traceback.print_exc()
@@ -464,9 +464,9 @@ class DependenciesAnalyser:
         if missing_deps:
             self._fill_single_providers_data(missing_deps, repo_missing, aur_missing, deps_data)
 
-            missing_subdeps = self.map_missing_deps(pkgs_data={**deps_data}, provided_map=provided_map, aur_index=aur_index,
-                                                    deps_checked=deps_checked, sort=False, deps_data=deps_data,
-                                                    watcher=watcher,
+            missing_subdeps = self.map_missing_deps(pkgs_data={**deps_data}, provided_map=provided_map,
+                                                    aur_index=aur_index, deps_checked=deps_checked, sort=False,
+                                                    deps_data=deps_data, watcher=watcher,
                                                     remote_provided_map=remote_provided_map,
                                                     remote_repo_map=remote_repo_map,
                                                     automatch_providers=automatch_providers,
@@ -588,7 +588,7 @@ class DependenciesAnalyser:
                 if repo_selected:
                     providers_data.update(pacman.map_updates_data(repo_selected))
                     # adding the providers as "installed" packages
-                    provided_map.update(pacman.map_provided(remote=True,  pkgs=repo_selected))
+                    provided_map.update(pacman.map_provided(remote=True, pkgs=repo_selected))
 
                 if aur_selected:
                     for pkgname, pkgdata in self.aur_client.gen_updates_data(aur_selected):
@@ -650,7 +650,7 @@ class DependenciesAnalyser:
         if pkgnames:
             to_ignore.update(pkgnames)
 
-        all_requirements = {req for reqs in pacman.map_required_by(pkgnames).values() for req in reqs if req not in to_ignore}
+        all_requirements = {r for reqs in pacman.map_required_by(pkgnames).values() for r in reqs if r not in to_ignore}
 
         if all_requirements:
             sub_requirements = self.map_all_required_by(all_requirements, to_ignore)
